==> roughpy-0.0.2a0.tar.gz: roughpy-0.0.2a0/tests/streams/test_brownian_stream.py <==
#  Copyright (c) 2023 the RoughPy Developers. All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without modification,
#  are permitted provided that the following conditions are met:
#
#  1. Redistributions of source code must retain the above copyright notice,
#  this list of conditions and the following disclaimer.
#
#  2. Redistributions in binary form must reproduce the above copyright notice,
#  this list of conditions and the following disclaimer in the documentation
#  and/or other materials provided with the distribution.
#
#  3. Neither the name of the copyright holder nor the names of its contributors
#  may be used to endorse or promote products derived from this software without
#  specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
#  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
#  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
#  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
#  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import pytest
from numpy.testing import assert_array_almost_equal
from roughpy import BrownianStream, DPReal, DyadicInterval


CONFIGURATIONS = [
    (2, 2),
    (2, 5),
    (5, 2),
    (10, 2)
]

@pytest.mark.parametrize("config", CONFIGURATIONS)
def test_brownian_stream_signature_multiplicative(config):
    stream = BrownianStream.with_generator(width=config[0], depth=config[1], dtype=DPReal)

    di1 = DyadicInterval(0, 0)
    di2 = DyadicInterval(1, 0)
    di3 = DyadicInterval(0, -1)

    left = stream.signature(di1, 5)
    right = stream.signature(di2, 5)
    top = stream.signature(di3, 5)

    assert_array_almost_equal(left*right, top), f"!={top-left*right}"

==> roughpy-0.0.3.tar.gz: roughpy-0.0.3/tests/streams/test_brownian_stream.py <==
#  Copyright (c) 2023 the RoughPy Developers. All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification,
#  are permitted provided that the following conditions are met:
#
#  1. Redistributions of source code must retain the above copyright notice,
#  this list of conditions and the following disclaimer.
#
#  2. Redistributions in binary form must reproduce the above copyright notice,
#  this list of conditions and the following disclaimer in the documentation
#  and/or other materials provided with the distribution.
#
#  3. Neither the name of the copyright holder nor the names of its contributors
#  may be used to endorse or promote products derived from this software without
#  specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
#  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL
#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
#  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
#  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
#  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import pytest
from numpy.testing import assert_array_almost_equal

from roughpy import BrownianStream, DPReal, DyadicInterval

CONFIGURATIONS = [
    (2, 2),
    (2, 5),
    (5, 2),
    (10, 2)
]


@pytest.mark.parametrize("config", CONFIGURATIONS)
def test_brownian_stream_signature_multiplicative(config):
    stream = BrownianStream.with_generator(width=config[0], depth=config[1],
                                           dtype=DPReal)

    di1 = DyadicInterval(0, 0)
    di2 = DyadicInterval(1, 0)
    di3 = DyadicInterval(0, -1)

    left = stream.signature(di1, 5)
    right = stream.signature(di2, 5)
    top = stream.signature(di3, 5)

    assert_array_almost_equal(left * right, top), f"!={top - left * right}"
